#
# spec file for package prboom-plus
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           prboom-plus
Version:        2.6.66
Release:        3.1
Summary:        DOOM source port with demo compatibility
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Shoot
URL:            http://prboom-plus.sf.net/

#Git-Clone:	https://github.com/coelckers/prboom-plus
Source:         https://github.com/coelckers/prboom-plus/archive/refs/tags/v%version.tar.gz
Patch1:         prboom-nodatetime.diff
Patch3:         prboom-hbar-all.diff
Patch4:         prboom-hbar-gradient.diff
BuildRequires:  Mesa-devel
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  fluidsynth-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpng-devel
BuildRequires:  libvorbis-devel
BuildRequires:  pcre-devel
BuildRequires:  portmidi-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(sdl2)
Suggests:       freedoom
Provides:       prboom = 2.6um
Obsoletes:      prboom <= 2.6

%description
PrBoom+ is a conservative Doom source port. It features:

* The removal of engine limits and bugs, like the visplane limit,
  savegame size limit, the tutti-frutti and medusa visual effects,
  and others.
* BOOM editing extensions, e.g. configurable animated/switch
  textures, deep water effect, scrolling walls/floors/ceilings,
  conveyor belts, translucent walls and sprites, friction effects,
  and generic linedef actions.
* Focus on retaining compatibility with the original Doom engines
  for the purpose of demo recording and playback.
* High resolution rendering of map geometry, optionally in OpenGL
  mode.

%prep
%autosetup -p0

%build
pushd prboom2/
%cmake -DDOOMWADDIR="%_datadir/doom" -DPRBOOMDATADIR="%_datadir/doom"
%cmake_build
popd

%install
s="$PWD"
pushd prboom2/
%cmake_install
# convenience symlink
b="%buildroot"
ln -s prboom-plus "$b/%_bindir/prboom"
install -Dm0644 ICONS/prboom-plus.svg "$b/%_datadir/icons/hicolor/scalable/apps/prboom-plus.svg"
install -Dm0644 ICONS/prboom-plus.desktop "$b/%_datadir/applications/prboom-plus.desktop"
install -Dm0644 ICONS/prboom-plus.bash "$b/%_datadir/bash-completion/completions/prboom-plus.bash"
popd
# TW switched doc location in %%cmake
(cd "%buildroot"; find "./%_datadir/doc" -type d -name prboom-plus | cut -b2-) >"$s/doc.files"
ls -al "$s/doc.files"

%if 0%{?suse_version} && 0%{?suse_version} < 1550
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files -f doc.files
%_bindir/*
%_datadir/doom/
%_mandir/*/*
%_datadir/applications/prboom-plus.desktop
%_datadir/icons/hicolor/scalable/apps/prboom-plus.svg
%_datadir/bash-completion/

%changelog
* Tue Apr  9 2024 Jan Engelhardt <jengelh@inai.de>
- Avoid making /usr/share/doc/packages itself part of the RPM
  following a change in the %%cmake macro
* Tue Apr  2 2024 Jan Engelhardt <jengelh@inai.de>
- Make filelist stricter, because it packaged
  /usr/share/doc/packages, a result of the %%configure macro
  changing in TW from ``--docdir=/usr/share/doc`` to
  ``--docdir=/usr/share/doc/packages``.
* Fri Nov  3 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.66
  * Move default data directory to XDG_DATA_HOME on Linux
  * Fix integer overflow during multiplication with
    realtic_clock_rate
  * Fix mid-texture vibrations when upper and middle textures
    overlap
  * Fixing wall texture bleed when a sector is inside the sky
  * Adjust music volume slider to match vanilla Doom
  * Use non-linear scaling for high volume levels
- Delete 0001-Fix-integer-overflow-during-multiplication-with-real.patch
  (merged)
* Wed Mar  2 2022 Jan Engelhardt <jengelh@inai.de>
- Add 0001-Fix-integer-overflow-during-multiplication-with-real.patch
  to resolve jaggy motion when gamespeed!=100 and when the
  program has run for 25+ minutes.
* Sat Feb 19 2022 Jan Engelhardt <jengelh@inai.de>
- Drop prboom-enable-tessellation.diff, this is enabled
  automatically when pkgconfig(GLU) is available (which we have).
* Sun Feb 13 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.2
  * added a prospective fix for OpenGL rendering: don't bleed
    walls through sky floors
  * no more crashes at textscreens (e.g. after MAP06, MAP11 or
    MAP20) after viewing finale picture upon finishing a level
    with UMAPINFO 'endpic' property
  * fixed freezing at TITLEPIC while using mousewheel in menus
  * fixed looping forever in G_NextWeapon()
  * UMAPINFO: fix 'entering' and 'enterpic' shown on exit levels
  * GL: adjust sky offsets for non-standard FOVs
  * fixed stuttering with uncapped framerate
  * added support for widescreen low resolutions
  * added REKKR to launcher string list
  * Portmidi: fix freeze after song change                                                                                                *  fixed scaled time interpolation when changing game speed
  * fixed wrong pitch of SFX when MIDI Player is set to SDL
  * UMAPINFO: fixed par times not showing
  * fixed demo playback warp consistency
  * added SKILL cheat to display current skill level
  * fixed calculation of interpolation frac value
  * added 'run' as a mouse-settable control (mouseb_speed)
* Mon Aug 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.6.1um
  * Allow colored blood to get set/overridden by DEHACKED
  * Made the Ouch Face fix available on all complevels
  * Added the autoload folder feature from Chocolate Doom
  * Made Doom sound quirk fixes available on all complevels
  * UMAPINFO: introduce the new 'label' field (#308)
  * Fixed a levelstat crash
  * Added a "-coop_spawns" parameter for using "coop in single-player" mode
  * UMAPINFO: entries without defined 'levelname' fall back to default
* Sat May  1 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 2.6um+git81 (15431b3a9aac)
  * Fix sky scaling for non-standard sky sizes
  * Support widescreen assets
  * Add OpenGL sprite fuzz options
- Update prboom-hbar-all.diff, prboom-hbar-gradient.diff
  from project.
* Fri Apr  9 2021 Jan Engelhardt <jengelh@inai.de>
- Switch to Oelcker's prboom-plus-um code base
- Update to release 2.6um and snapshot 2.6um+git69 (07925d634)
  * Support for UMAPINFO lump, customizable intermissions,
    customizable episode menu.
  * It is now possible to set individual key bindings to
    unassigned (completely disable a hotkey function)
  * Support for Compressed ZDoom BSP nodes.
  * 100 extra sprites (SP00..SP99) for use in DEH/BEX,
    200 extra sounds for use in DEH/BEX.
  * Add -statdump parameter from Chocolate Doom.
  * Add -stroller parameter.
  * Added new BEX property "Dropped item" for mobjs.
  * New demo format with "PR+UM" signature.
  * Add a "-pistolstart" command line parameter.
  * Add ALSA sequencer API backend for ALSA MIDI support.
  * Now defaults to ffmpeg for video encoding
    (switched from previous oggenc2 & x264).
- Drop 0001-fix-heap-buffer-overflows-in-UDP-code-CVE-2019-20797.patch
  (merged), prboom-types1.diff (obsolete),
  prboom-types2.diff (obsolete), prboom-hbar-color.diff (folded
  into prboom-hbar-gradient.diff)
* Tue Jun  9 2020 Jan Engelhardt <jengelh@inai.de>
- Add 0001-fix-heap-buffer-overflows-in-UDP-code-CVE-2019-20797.patch
  [CVE-2019-20797, boo#1171974]
* Sun Jun  7 2020 Jan Engelhardt <jengelh@inai.de>
- Set CFLAGS+=-fcommon.
* Fri Aug 23 2019 Jan Engelhardt <jengelh@inai.de>
- Disable DUMB backend because of its removal from Factory
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- Enable DUMB music backend
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 2.5.1.5 SVN4532
  * Move to SDL2
  * Added the "cap_fps" config variable
  * The Del key can be used to clear key bindings in the setup menu.
  * Added "Weapon Attack Alignment" option to align the weapon while
    shooting. Possible values: "off" (doom behavior), "horizontal",
    "centered" and "bobbing" for bobbing during fire.
  * Removed the "Strafe 50 on Turns" and "Two-key strafe50:
    StrafeOn + MoveLR = strafe50" feature.
* Tue Mar 29 2016 jengelh@inai.de
- Update to version 2.5.1.4
  * Added "Allow Jump" and "Allow Vertical Aiming" option on
  Prboom-plus 'bad' compatibility settings" page.
  * Added a "Backpack Changes Thresholds" option
  * "Use GL surface for software mode" mode now works much faster
  if gl_finish is 0 in config.
  * Better support for Chex Quest,
  * Fixed the classic "Long Wall" rendering error.
* Sun Mar 29 2015 jengelh@inai.de
- Avoid strange inequality in Provides tag
* Mon Nov 11 2013 jengelh@inai.de
- Update to snapshot 2.5.1.4 SVN4355
  * Added "Fix clipping problems in large levels" option.
  * Added "gl_finish" config variable.
  * Added a "Health Bar Above Monsters" option (health_bar* config
  variables; GL only).
  * Added a "Things appearance" automap option. Possible values:
  "classic", "scaled" and "icons".
  * Added "notarget" and "fly" cheat codes.
  * Added MBF's "-beta" codepointers.
  * Added a new HUD.
  * Added "shaders" sector light mode.
  * Support "Classic Doom" WAD files of Doom 3 BFG Edition and HACX
  1.2 IWAD
  * Restricted mouse look (Heretic-style Y-shearing) now is available
  in software mode.
  * Added a crosshair. Three different crosshair graphics are for
  choice: cross, angle and dot. Extra features are changing
  crosshair colors according to the player's health and/or on sight
  of a target.
  * "Use GL surface for software mode" mode now works much faster if
  gl_finish is 0 in config.
  * Ability to use e.g. doom1.wad as a resource for a doom2 IWAD,
  e.g. freedoom (prboom-plus -iwad freedoom.wad -file doom1.wad).
* Sun Mar 24 2013 jengelh@inai.de
- Update to new upstream release 2.5.1.3
  * Added device selection to portmidi player. Controlled by the
  snd_mididev config variable. See stdout.txt for list of
  available devices.
  * Added a progress bar for demo skipping during re-recording.
  * Added key binding options for start/stop and fast-forward when
  watching demos.
  * Added a key binding option to restart the current map.
  * Added a "Default compatibility level" GUI entry.
  * Support for 16 sprite rotations. http://zdoom.org/wiki/Sprite#Angles
  * New HUDs. HUDs definitions are moved to the
  "prboom-plus.wad/-prbhud-" lump.
- Remove prboom-protos.diff, merged upstream
* Fri May 25 2012 joop.boonen@opensuse.org
- Corrected typo in spec file
* Fri May 25 2012 joop.boonen@opensuse.org
- Added BuildRequires automake
* Wed Aug  3 2011 jengelh@medozas.de
- Enable missing USE_GLU_TESS for the self-referencing sector hack
  to be rendered.
* Mon Jun 20 2011 jengelh@medozas.de
- Update to new upstream release 2.5.1.1:
  * Support was added for sound fonts, OPL2 emulation, mouse wheel,
  changing resolution on the fly, interpolation of automap, and the
  "use GL surface for software mode" video option for the ability
  to use hardware vsync in software mode.
* Tue Nov 16 2010 jengelh@medozas.de
- Update to new upstream release 2.5.0.8a:
  * Support for textured automap was added. Compatibility with Doom
  1.2 was improved. New HUDs and bugs were fixed.
* Mon Aug 23 2010 jengelh@medozas.de
- Update to new upstream release 2.5.0.7:
  * A lot of compatibility and improvements, many bug fixes, and
  several new features were added, including support for DeePBSP and
  uncompressed ZDBSP nodes and dynamic music changing... through the
  new MUSINFO lump. On the GLBoom+ front, there is support for GZDoom
  skyboxes, custom detail texture definitions, and blending of
  animated flats and wall textures.
